@@ -18,4 +18,5 @@ class EventRoutingBackendsConfig(AppConfig):
         """
         super(EventRoutingBackendsConfig, self).ready()
         # pylint: disable=import-outside-toplevel, unused-import
-        from event_routing_backends.processors.caliper import event_transformers
+        from event_routing_backends.processors.caliper import event_transformers as caliper_event_transformers
+        from event_routing_backends.processors.xapi import event_transformers as xapi_event_transformers
